library(testthat)
library(quantspec)

#' @importFrom testthat test_package
test_check("quantspec")